remote_camera_info_handler

Function remote_camera_info_handler 

async fn remote_camera_info_handler(
    __arg0: State<BraidAppState>,
    session_key: SessionKey,
    __arg2: Path<String>,
) -> impl IntoResponse
Query the mainbrain configuration to get data required for camera settings.

Note that this does not change the state of the mainbrain to register anything about the camera but only queries for its configuration. Registration of a new camera is done by braid_types::BraidHttpApiCallback::NewCamera.